@@ -4,8 +4,8 @@
 ( cd opt/kde/share/doc/HTML/et/kdf ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kdm ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/kit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/kit ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kig ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kig ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kpf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kpf ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/ktuberling ; rm -rf common )
@@ -20,22 +20,34 @@
 ( cd opt/kde/share/doc/HTML/et/kdat ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kdvi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kdvi ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kget ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kget ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kgpg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kgpg ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kmag ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kmag ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kodo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kodo ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kolf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kolf ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kpat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kpat ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kpdf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kpdf ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/korn ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/korn ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kppp ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kppp ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/krdc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/krdc ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/krfb ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/krfb ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/ksim ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/ksim ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/lisa ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/lisa ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kxkb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kxkb ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kalzium ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kalzium ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/katomic ; rm -rf common )
@@ -46,6 +58,8 @@
 ( cd opt/kde/share/doc/HTML/et/kbounce ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kbattleship ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kbattleship ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kaboodle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kaboodle ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/knewsticker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/knewsticker ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/khangman ; rm -rf common )
@@ -54,6 +68,8 @@
 ( cd opt/kde/share/doc/HTML/et/kfloppy ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/cervisia ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/cervisia ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/khexedit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/khexedit ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kpercentage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kpercentage ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kandy ; rm -rf common )
@@ -70,6 +86,8 @@
 ( cd opt/kde/share/doc/HTML/et/kedit ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kfind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kfind ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kiten ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kiten ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kjots ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kjots ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kmail ; rm -rf common )
@@ -96,16 +114,28 @@
 ( cd opt/kde/share/doc/HTML/et/kwin4 ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/lskat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/lskat ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kgoldrunner ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kcoloredit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/klipper ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/klipper ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kvoctrain ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kmousetool ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kmousetool ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kompare ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kontact ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kontact ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/konsole ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/konsolekalendar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kcachegrind ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kpackage ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/khelpcenter/faq ; rm -rf common )
@@ -128,10 +158,16 @@
 ( cd opt/kde/share/doc/HTML/et/konquest ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kverbos ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kverbos ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kwallet ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kwallet ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kweather ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/kwuftpd ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kxsldbg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kwifimanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kmenuedit ; rm -rf common )
@@ -144,8 +180,6 @@
 ( cd opt/kde/share/doc/HTML/et/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/kxconfig ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/kxconfig ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf qpl-license.html )
@@ -182,6 +216,8 @@
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/et/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf doxygen.css )
@@ -196,12 +232,16 @@
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/et/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/et/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/et/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/et/common ; rm -rf fdl-license.html )
@@ -276,10 +316,14 @@
 ( cd opt/kde/share/doc/HTML/et/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/kmixcfg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kcontrol/desktopbehavior ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/lanbrowser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/passwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kcontrol/panelappearance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/ebrowsing ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/background ; rm -rf common )
@@ -334,38 +378,12 @@
 ( cd opt/kde/share/doc/HTML/et/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/kcmtaskbar ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/kcontrol/kthememgr ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/kcmfontinst ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/crashes ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/crashes ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/babel ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/babel ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/kuick ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/kuick ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/webarchiver ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/webarchiver ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/domtreeviewer ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/domtreeviewer ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/smbmounter ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/smbmounter ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/imgallery ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/imgallery ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/khtmlsettings ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/khtmlsettings ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/validators ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/validators ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/konq-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/uachanger ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/uachanger ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/mediaplayer ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/mediaplayer ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/dirfilter ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/konq-plugins/dirfilter ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kbabel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kbabel ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kalarm ; rm -rf common )
@@ -376,8 +394,12 @@
 ( cd opt/kde/share/doc/HTML/et/kdeprint ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kasteroids ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kasteroids ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kbruch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kbruch ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/keduca ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/keduca ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kgamma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kgamma ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kmessedwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kicker ; rm -rf common )
@@ -386,6 +408,8 @@
 ( cd opt/kde/share/doc/HTML/et/klines ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kmines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kmines ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kmouth ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kmouth ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kmplot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kmplot ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/knotes ; rm -rf common )
@@ -394,6 +418,8 @@
 ( cd opt/kde/share/doc/HTML/et/kpager ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kpaint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kpaint ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kopete ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kopete ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kpilot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kpilot ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kpoker ; rm -rf common )
@@ -414,10 +440,10 @@
 ( cd opt/kde/share/doc/HTML/et/ktouch ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kwrite ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kwrite ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/megami ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/megami ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kreversi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kreversi ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/ksplashml ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/ksplashml ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kdebugdialog ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kblackbox ; rm -rf common )
@@ -434,12 +460,12 @@
 ( cd opt/kde/share/doc/HTML/et/klettres ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kfouleggs ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/kaphorism ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/kaphorism ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kghostview ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kghostview ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/klickety ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/klickety ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kpovmodeler ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kjumpingcube ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kenolaba ; rm -rf common )
@@ -494,6 +520,8 @@
 ( cd opt/kde/share/doc/HTML/et/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kate-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/umbrello ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/umbrello ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/konqueror ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/konqueror ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/korganizer ; rm -rf common )
